@@ -22,9 +22,6 @@ princals <- function (data, ndim = 2, levels = "ordinal", ordinal, knots, ties =
       knots <- levelprep$knotList
     }
     
-    ## --- prep copies
-    if ((length(copies) == 1) && (any(ordinal == FALSE))) copies <- (!ordinal)+1
-    
     
     ## prep Gifi object
     g <- makeGifi(data = data, knots = knots, degrees = reshape(degrees, nvars), ordinal = reshape(ordinal, nvars),
@@ -108,7 +105,7 @@ princals <- function (data, ndim = 2, levels = "ordinal", ordinal, knots, ties =
    
    res <- list(transform = transform, rhat = rhat, evals = evals, objectscores = objectscores, scoremat = scoremat, quantifications = quantifications,
                dmeasures = dmeasures, lambda = lambda, weights = weights, loadings = t(loadings), ntel = ntel, f = f, 
-               data = data_orig, datanum = data, ndim = ndim, knots = knotlist, degrees = degvec, ordinal = ordvec, copies = copies,
+               data = data_orig, datanum = data, ndim = ndim, knots = knotlist, degrees = degvec, ordinal = ordvec,
                call = match.call())
    class(res) <- c("princals", "gifi")
    return(res)
